import {
  InnerBlocks,
  useBlockProps,
  useInnerBlocksProps,
} from "@wordpress/block-editor";
import { useSelect, dispatch } from "@wordpress/data";
import { useEffect } from '@wordpress/element';
import './editor.scss';
const ALLOWED_BLOCKS = ["ucla-wordpress-plugin/tab-item"];
const TEMPLATE = [
  ["ucla-wordpress-plugin/tab-item", {}],
  ["ucla-wordpress-plugin/tab-item", {}],
];
const Edit = ({ attributes, setAttributes, clientId, isSelected }) => {
  let {tabValues, currentTab} = attributes;
  const childBlockContent = useSelect(
    select => select( 'core/block-editor' ).getBlocks( clientId )
  );
  const blockProps = useBlockProps();
  const {children, ...innerBlocksProps} = useInnerBlocksProps( blockProps,  {
    allowedBlocks: ALLOWED_BLOCKS,
    template: TEMPLATE,
    orientation: 'horizontal',
  });
  const onTabClick = (value, clientId) => {
    dispatch('core/block-editor').selectBlock(clientId)
    setAttributes({currentTab: value})
  }

  useEffect(
    () => {
      const tabValues = childBlockContent.map(({clientId, attributes: {tabLabel}})=>({clientId, tabLabel}));
      setAttributes({tabValues})
    }, [childBlockContent]  
  );
  return (
    <div {...innerBlocksProps}>
      <div className="ucla-tabs">
        <nav className="ucla-tabslist" role="tablist">
          {tabValues && tabValues.map(({clientId, tabLabel}, index) => {
          let formatTabLabel = tabLabel.replace(/\s+/g, '-').toLowerCase();
          return (
              <button key={clientId} onClick={()=>onTabClick(index, clientId)} className={`ucla-tablink${currentTab === index ? ' is-active' : ''}`} id={`ucla-tab-${formatTabLabel}-${index}`}>{tabLabel}</button>
          )})}
        </nav>
        <section className="ucla-tabpanels">
          {children}
        </section>
      </div>
      {isSelected &&
          <InnerBlocks.ButtonBlockAppender />
        }
    </div>  
  );
}
export default Edit;